pub struct PublicApiInstrumentationInformation { /* private fields */ }Expand description
Information about the public API being instrumented.
This struct is used to pass information about the public API being instrumented
to the PublicApiInstrumentationPolicy.
It contains the name of the API, which is used to create a span for distributed tracing and any additional per-API attributes that might be needed for instrumentation.
If the PublicApiInstrumentationPolicy policy detects a PublicApiInstrumentationInformation in the context,
it will create a span with the API name and any additional attributes.
Implementations