pub struct RetryHeaders {
pub retry_headers: Vec<HeaderName>,
}Expand description
Headers that may be used to determine how long to wait before retrying a request.
The boolean indicates if the header is a standard Retry-After header (true)
or a service-specific header (false).
Fields
retry_headers: Vec<HeaderName>The headers that may indicate how long to wait before retrying.